@@ -347,7 +347,8 @@ regC <- function(formula, w, data, digits=3, anova=FALSE,
     if(printC==TRUE & k==2) 
     {
       imagename <- paste("regC.plot.", unclass(Sys.time()), ".png", sep="")
-      grDevices::png(filename=imagename, width=4, height=4, units="in", type="cairo", pointsize=8, res=300, antialias="default")
+      grDevices::png(filename=imagename, width=4, height=4, units="in", 
+                     type=getPNGtype(), pointsize=8, res=300, antialias="default")
       class(imagename) <- "image"
       printC(imagename)
     }
